package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.util.SubjectDNUtil;

public class TBSCertificateStructure extends ASN1Encodable implements X509ObjectIdentifiers, PKCSObjectIdentifiers {
   ASN1Sequence seq;
   DERInteger version;
   DERInteger serialNumber;
   AlgorithmIdentifier signature;
   X509Name issuer;
   Time startDate;
   Time endDate;
   X509Name subject;
   SubjectPublicKeyInfo subjectPublicKeyInfo;
   DERBitString issuerUniqueId;
   DERBitString subjectUniqueId;
   X509Extensions extensions;

   public static TBSCertificateStructure getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static TBSCertificateStructure getInstance(Object obj) {
      if (obj instanceof TBSCertificateStructure) {
         return (TBSCertificateStructure)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new TBSCertificateStructure((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public TBSCertificateStructure(ASN1Sequence seq) {
      int var2 = 0;
      this.seq = seq;
      if (seq.getObjectAt(0) instanceof DERTaggedObject) {
         this.version = DERInteger.getInstance(seq.getObjectAt(0));
      } else {
         var2 = -1;
         DERInteger var3;
         var3 = new DERInteger.<init>(0);
         this.version = var3;
      }

      this.serialNumber = DERInteger.getInstance(seq.getObjectAt(var2 + 1));
      this.signature = AlgorithmIdentifier.getInstance(seq.getObjectAt(var2 + 2));
      DEREncodable var6;
      if ((var6 = seq.getObjectAt(var2 + 3)) instanceof ASN1Sequence) {
         this.issuer = X509Name.getInstance(SubjectDNUtil.sortDN((ASN1Sequence)var6, "cn.com.infosec.jce.SortIssuerDN"));
      } else {
         this.issuer = (X509Name)var6;
      }

      ASN1Sequence var10003 = (ASN1Sequence)seq.getObjectAt(var2 + 4);
      this.startDate = Time.getInstance(var10003.getObjectAt(0));
      this.endDate = Time.getInstance(var10003.getObjectAt(1));
      if ((var6 = seq.getObjectAt(var2 + 5)) instanceof ASN1Sequence) {
         this.subject = X509Name.getInstance(SubjectDNUtil.sortDN((ASN1Sequence)var6, "cn.com.infosec.jce.SortDN"));
      } else {
         this.subject = (X509Name)var6;
      }

      this.subjectPublicKeyInfo = SubjectPublicKeyInfo.getInstance(seq.getObjectAt(var2 += 6));

      for(int var7 = seq.size() - var2 - 1; var7 > 0; --var7) {
         DERTaggedObject var4;
         int var5;
         if ((var5 = (var4 = (DERTaggedObject)seq.getObjectAt(var2 + var7)).getTagNo()) != 1) {
            if (var5 != 2) {
               if (var5 == 3) {
                  this.extensions = X509Extensions.getInstance(var4);
               }
            } else {
               this.subjectUniqueId = DERBitString.getInstance(var4, false);
            }
         } else {
            this.issuerUniqueId = DERBitString.getInstance(var4, false);
         }
      }

   }

   public int getVersion() {
      return this.version.getValue().intValue() + 1;
   }

   public DERInteger getVersionNumber() {
      return this.version;
   }

   public DERInteger getSerialNumber() {
      return this.serialNumber;
   }

   public AlgorithmIdentifier getSignature() {
      return this.signature;
   }

   public X509Name getIssuer() {
      return this.issuer;
   }

   public Time getStartDate() {
      return this.startDate;
   }

   public Time getEndDate() {
      return this.endDate;
   }

   public X509Name getSubject() {
      return this.subject;
   }

   public SubjectPublicKeyInfo getSubjectPublicKeyInfo() {
      return this.subjectPublicKeyInfo;
   }

   public DERBitString getIssuerUniqueId() {
      return this.issuerUniqueId;
   }

   public DERBitString getSubjectUniqueId() {
      return this.subjectUniqueId;
   }

   public X509Extensions getExtensions() {
      return this.extensions;
   }

   public DERObject toASN1Object() {
      return this.seq;
   }
}
